Implementation instructions for X-Promo and Inbox
=================================================

Requirements
------------

Import the appblocks and utilities libraries from the SDK git hub repo:

git://github.zynga.com/sdk/zynga-android-sdk.git

Get custom_themes.xml found [here] (http://github.zynga.com/sdk/android-java-game/blob/master/res/values/custom_themes.xml) which is part of our sample Java Game repo.
Copy this file into your project's res/values directory.

Add the following to your AndroidManifest.xml:

    <uses-permission android:name="android.permission.INTERNET"/>
    <uses-permission android:name="android.permission.WRITE_EXTERNAL_STORAGE"/>
    <uses-permission android:name="android.permission.ACCESS_NETWORK_STATE"/>
    <uses-permission android:name="android.permission.WRITE_SETTINGS" />


        <activity android:name="com.zynga.sdk.msc.XPromoActivity"
                  android:label="@string/app_name"
                  android:theme="@style/NoTitleBarSemiTransparent"
                  android:screenOrientation= "landscape"
                  android:exported="false">
        </activity>

The X-Promo screen should be orientation locked to your games default orientation ("landscape" or "portrait").

Pick one of the following methods for implementing X-Promo or InBox, additional instructions for InBox can be found below.


(1) (Recommended) Create the button in Java
------------------------------------------

	// Grab the layout you want to place it in
	LinearLayout l = (LinearLayout)findViewById(R.id.main_layout);
	// Create the button:   (context, attributeSet, gameId, zid, masterZid)
	XPromoButton dogButton = new XPromoButton(this, null, "1025", "32144993307", "32144993307");
	l.addView(dogButton);

If you don't have a master zid, null or "" is fine.

Available constructors:

	// No Auth
	XPromoButton(Context context, AttributeSet aSet, String gameId)
	// Zid only
	XPromoButton(Context context, AttributeSet aSet, String gameId, String zid, String masterZid, String uuid, String appId)
	// Fb no Zid
	XPromoButton(Context context, AttributeSet aSet, String gameId, String fbUid, String fbAccessToken, String fbExpires, String uuid, String appId)
	// Fb with Zid
	XPromoButton(Context context, AttributeSet aSet, String gameId, String fbUid, String fbAccessToken, String fbExpires, String zid, String masterZid, String uuid, String appId)

If you need to update values during runtime, for example if the user logs into facebook call the appropriate setValues:

	// No Auth
	setValues(String gameId)
	// Zid only
	setValues(String gameId, String zid, String masterZid, String uuid, String appId)
	// Fb no Zid
	setValues(String gameId, String fbUid, String fbAccessToken, String fbExpires, String uuid, String appId)
	// Fb with Zid
	setValues(String gameId, String fbUid, String fbAccessToken, String fbExpires, String zid, String masterZid, String uuid, String appId)


(2) Add the button in an XML layout
----------------------------------

Add the button to your XML layout.

Sample: 

    <com.zynga.sdk.msc.XPromoButton
        android:id="@+id/dog_button"
        android:layout_width="wrap_content"
        android:layout_height="wrap_content"
        android:layout_gravity="center_horizontal"
        android:text="XPromoButton" >
    </com.zynga.sdk.msc.XPromoButton>

From java find the button and call setValues passing which ever properties you may have:

Sample (Only gameId no auth):

	XPromoButton dogButton = (XPromoButton)findViewById(R.id.dog_button);
	dogButton.setValues("1025");

If you need to update values during runtime, for example if the user logs into facebook call the appropriate setValues on your button:
You may pass null or "" for any parameter you don't have.

	// No Auth
	setValues(String gameId)
	// Zid only
	setValues(String gameId, String zid, String masterZid, String uuid, String appId)
	// Fb no Zid
	setValues(String gameId, String fbUid, String fbAccessToken, String fbExpires, String uuid, String appId)
	// Fb with Zid
	setValues(String gameId, String fbUid, String fbAccessToken, String fbExpires, String zid, String masterZid, String uuid, String appId)


(3) (Not recommended) Invoke the activity through an intent (Advanced)
---------------------------------------------------------------------
This is not recommended as you will lose the badge count on the button as well as any other functionality that MSC may integrate into the button over time.

The intent to launch the activity looks like this:

        Intent i = new Intent(c, XPromoActivity.class);
        i.putExtra(XPromoActivity.BUNDLE_GAME_ID, mGameId);
        i.putExtra(XPromoActivity.BUNDLE_UID, mUid);
        i.putExtra(XPromoActivity.BUNDLE_ACCESS_TOKEN, mAccessToken);
        i.putExtra(XPromoActivity.BUNDLE_EXPIRES, mExpires);
        i.putExtra(XPromoActivity.BUNDLE_ZID, mZid);
        i.putExtra(XPromoActivity.BUNDLE_MASTER_ZID, mMasterZid);
        i.putExtra(XPromoActivity.BUNDLE_UUID, mUuid);
        i.putExtra(XPromoActivity.BUNDLE_APP_ID, mAppId);
        c.startActivity(i);

If you have done your own preload you may pass that webview as well before invoking the intent:

			XPromoActivity.setWebView(mWebView);

All this functionality can been seen in the source for XPromoButton


InBox functionality
--------------------

Either during app start-up, just before button creation, or very shortly after creation call:

	        XPromoButton.setInboxMode("url_to_your_inbox");

url_to_your_inbox should be provided by someone from the MSC team who created / setup your inbox.


Additional Configuration Options
--------------------------------
### Methods on XPromoButton ###

All these methods should be called on your instance of XPromoButton

	// Add an on click listener to dog button to invoke, references stored are
	// weak references so registering a listener will not prevent your listener
	// from being garbage collected if it is not referenced anywhere else. 
	public void addClickListener(OnClickListener newListener)
	// Remove a registered on click listener
	public void removeClickListener(OnClickListener removeListener)
	
	// Methods to set a label below the dog button:
	// Setting text to null, "" or int 0 will cause the text to be hidden again. (it is already hidden by default)
	public void setButtonLabel(String text)
	public void setButtonLabel(int resId)
	public void setButtonLabel(String text, Typeface tf, int style)
	public void setButtonLabel(int resId, Typeface tf, int style)
	public void setButtonLabel(String text, Typeface tf, int style, float fontSize)
	public void setButtonLabel(int resId, Typeface tf, int style, float fontSize)
	public void setButtonLabel(int resId, float fontSize, int color)
	public void setButtonLabel(String text, float fontSize, int color)
	public void setButtonLabel(String text, Typeface tf, int style, float fontSize, int color)
	public void setButtonLabel(int resId, Typeface tf, int style, float fontSize, int color)

	// Set a custom button image for display
	public void setCustomButtonImage(int resId)
	public void setCustomButtonImage(Drawable d)
	
	// If you need to manually update button count (this is normally handled automaticly as part of the button operation)
	updateCount(int newCount)
	

### Methods on XPromoActivity ###

These are all static methods can be invoked any time, preferably very early on in the lifecycle.
	
	// Use to listen for badge counter updates from Inbox / Xpromo, this is
	// already used by XPromoButton. But you may add your own listener for
	// what ever additional purpose you require. (Disply inbox count in some other UI element)
	addCountListener(XPromoCountListener listener)
	removeCountListener(XPromoCountListener listener)
	
	// This method is only for development purposes, titles SHOULD NOT SHIP WITH THIS TURNED ON.
	// It enables all JavaScript alerts to show on screen as toasts, also allows manual over ride of the front end URL and the DAPI url used by the page loaded, and spoofing of device id.
	setDebugMode(boolean onOff)
	
	// Only supported in debug mode, allows spoofing of other device ids for testing
	setDeviceId(String deviceId)
	
	// Only supported in debug mode, allows you to replace the URL being loaded for the XPromo / Inbox
	// For inbox operation see section above on Inbox Functionality
	overridePromoUrl(String newUrl)

	// Only supported in debug mode, allows you to replace the DAPI URL used by the XPromo / Inbox page
	overrideDAPIurl(String newUrl)
	String getPromoUrl()
	
	